@@ -39,7 +39,7 @@ scheduler = require("nonebot_plugin_apscheduler").scheduler
 driver = get_driver()
 
 
-__version__ = "0.3.1.2"
+__version__ = "0.3.1.3"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
@@ -57,32 +57,35 @@ __plugin_meta__ = PluginMetadata(
 @up.handle()
 async def _(matcher:Matcher,event: NoticeEvent):
     args = event.dict()
-    matcher.set_arg('txt',args)
+    if args['notice_type'] != 'offline_file':
+        matcher.set_arg('txt',args)
+    else:
     # 检查下载路径是否存在
     # logger.info('检查下载路径是否存在')
-    # if not Path(l4_file).exists():
-    #     await up.finish("你填写的路径不存在辣")
-    # if not Path(map_path).exists():
-    #     await up.finish("这个路径并不是求生服务器的路径，请再看看罢")
-    #     # args = event.dict()
-    # # if args['notice_type'] != 'offline_file':  # 群聊值响应超管
-    # #     return
-    # url = txt['file']['url']
-    # name: str = txt['file']['name']
-    # # user_id = txt['user_id']
-    # # 如果不符合格式则忽略
-    # if not name.endswith(file_format):
-    #     return
-    # await up.send('已收到文件，开始下载')
-    # sleep(1)   # 等待一秒防止因为文件名获取出现BUG
-    # vpk_files = await updown_l4d2_vpk(map_path,name,url)
-    # if vpk_files:
-    #     logger.info('检查到新增文件')
-    #     mes = "解压成功，新增以下几个vpk文件"
-    # else:
-    #     mes = "你可能上传了相同的文件，或者解压失败了捏"
-            
-    # await up.finish(mes_list(mes,vpk_files))
+        l4_file_path = l4_file[CHECK_FILE]
+        # 检查下载路径是否存在
+        logger.info(l4_file_path)
+        if not Path(l4_file_path).exists():
+            await up.finish("你填写的路径不存在辣")
+        if not Path(map_path).exists():
+            await up.finish("这个路径并不是求生服务器的路径，请再看看罢")
+            # args = event.dict()
+        # if args['notice_type'] != 'offline_file':  # 群聊值响应超管
+        #     return
+        url = args['file']['url']
+        name: str = args['file']['name']
+        # user_id = txt['user_id']
+        # 如果不符合格式则忽略
+        await up.send('已收到文件，开始下载')
+        sleep(1)   # 等待一秒防止因为文件名获取出现BUG
+        vpk_files = await updown_l4d2_vpk(map_path,name,url)
+        if vpk_files:
+            logger.info('检查到新增文件')
+            mes = "解压成功，新增以下几个vpk文件"
+        else:
+            mes = "你可能上传了相同的文件，或者解压失败了捏"
+                
+        await up.finish(mes_list(mes,vpk_files))
 
 
 @up.got("is_sure",prompt="请选择上传位置（输入阿拉伯数字)")    
@@ -118,7 +121,7 @@ async def _(matcher: Matcher):
         return
     await up.send('已收到文件，开始下载')
     sleep(1)   # 等待一秒防止因为文件名获取出现BUG
-    vpk_files = await updown_l4d2_vpk(map_path,name,url)
+    vpk_files = await updown_l4d2_vpk(Path(l4_file_path,vpk_path),name,url)
     if vpk_files:
         logger.info('检查到新增文件')
         mes = "解压成功，新增以下几个vpk文件"
